diff --git a/autotest.sh b/autotest.sh
index 0c59ee51a05dc2eb5c18b21cb2e4c89c980bfcee..4562b3ed08a553cea5671ccf6e9ef266a89f2afe 100755
--- a/autotest.sh
+++ b/autotest.sh
@@ -130,11 +130,11 @@ EOF
 	rm -rf coverage-html-$1
 	mkdir coverage-html-$1
 	php -f enable_all.php
-	if [ "$1" == "pgsql" ] ; then
-		# no coverage with pg - causes segfault on ci.tmit.eu - reason unknown
-		phpunit --configuration phpunit-autotest.xml --log-junit autotest-results-$1.xml
-	else
+	if [ "$1" == "sqlite" ] ; then
+		# coverage only with sqlite - causes segfault on ci.tmit.eu - reason unknown
 		phpunit --configuration phpunit-autotest.xml --log-junit autotest-results-$1.xml --coverage-clover autotest-clover-$1.xml --coverage-html coverage-html-$1
+	else
+		phpunit --configuration phpunit-autotest.xml --log-junit autotest-results-$1.xml
 	fi
 }